@@ -55,8 +55,15 @@ import signal
 import time
 import collections
 try:
-    # Python 3.3+
-    from ipaddress import ip_address
+    # Python 3.3+ or backport
+    from ipaddress import ip_address as _ip_address  # pylint: disable=F0401
+
+    def ip_address(x):
+        try:
+            x = x.decode('ascii')
+        except AttributeError:
+            pass
+        return _ip_address(x)
 except ImportError:
     # Python 2.6, 2.7, 3.2
     from ipaddr import IPAddress as ip_address
