@@ -3,16 +3,22 @@
 negotiated.py
 
 Created by Thomas Mangin on 2012-07-19.
-Copyright (c) 2009-2013 Exa Networks. All rights reserved.
+Copyright (c) 2009-2015 Exa Networks. All rights reserved.
 """
 
-from exabgp.bgp.message.open.asn import ASN,AS_TRANS
+from exabgp.bgp.message.open.asn import ASN
+from exabgp.bgp.message.open.asn import AS_TRANS
 from exabgp.bgp.message.open.holdtime import HoldTime
-from exabgp.bgp.message.open.capability.id import CapabilityID as CID,REFRESH
+from exabgp.bgp.message.open.capability.capability import Capability
+from exabgp.bgp.message.open.capability import REFRESH
 from exabgp.bgp.message.open.routerid import RouterID
 
+
 class Negotiated (object):
-	def __init__ (self,neighbor):
+	MAX_SIZE = 4096
+	FREE_SIZE = MAX_SIZE - 19 - 2 - 2
+
+	def __init__ (self, neighbor):
 		self.neighbor = neighbor
 
 		self.sent_open = None
@@ -25,60 +31,60 @@ class Negotiated (object):
 		self.asn4 = False
 		self.addpath = RequirePath()
 		self.multisession = False
-		self.msg_size = 4096
+		self.msg_size = self.MAX_SIZE
 		self.operational = False
-		self.refresh = REFRESH.absent
+		self.refresh = REFRESH.ABSENT  # pylint: disable=E1101
 		self.aigp = None
 
-	def sent (self,sent_open):
+	def sent (self, sent_open):
 		self.sent_open = sent_open
 		if self.received_open:
-			self._negociate()
+			self._negotiate()
 
-	def received (self,received_open):
+	def received (self, received_open):
 		self.received_open = received_open
 		if self.sent_open:
-			self._negociate()
-		#else:
-		#	import pdb; pdb.set_trace()
+			self._negotiate()
 
-	def _negociate (self):
+	def _negotiate (self):
 		sent_capa = self.sent_open.capabilities
 		recv_capa = self.received_open.capabilities
 
 		self.holdtime = HoldTime(min(self.sent_open.hold_time,self.received_open.hold_time))
 
 		self.addpath.setup(self.sent_open,self.received_open)
-		self.asn4 = sent_capa.announced(CID.FOUR_BYTES_ASN) and recv_capa.announced(CID.FOUR_BYTES_ASN)
-		self.operational = sent_capa.announced(CID.OPERATIONAL) and recv_capa.announced(CID.OPERATIONAL)
+		self.asn4 = sent_capa.announced(Capability.CODE.FOUR_BYTES_ASN) and recv_capa.announced(Capability.CODE.FOUR_BYTES_ASN)
+		self.operational = sent_capa.announced(Capability.CODE.OPERATIONAL) and recv_capa.announced(Capability.CODE.OPERATIONAL)
 
 		self.local_as = self.sent_open.asn
 		self.peer_as = self.received_open.asn
 		if self.received_open.asn == AS_TRANS:
-			self.peer_as = recv_capa[CID.FOUR_BYTES_ASN]
+			self.peer_as = recv_capa[Capability.CODE.FOUR_BYTES_ASN]
 
 		self.families = []
-		if recv_capa.announced(CID.MULTIPROTOCOL_EXTENSIONS) \
-		and sent_capa.announced(CID.MULTIPROTOCOL_EXTENSIONS):
-			for family in recv_capa[CID.MULTIPROTOCOL_EXTENSIONS]:
-				if family in sent_capa[CID.MULTIPROTOCOL_EXTENSIONS]:
+		if \
+			recv_capa.announced(Capability.CODE.MULTIPROTOCOL) and \
+			sent_capa.announced(Capability.CODE.MULTIPROTOCOL):
+			for family in recv_capa[Capability.CODE.MULTIPROTOCOL]:
+				if family in sent_capa[Capability.CODE.MULTIPROTOCOL]:
 					self.families.append(family)
 
-		if recv_capa.announced(CID.ENHANCED_ROUTE_REFRESH) and sent_capa.announced(CID.ENHANCED_ROUTE_REFRESH):
-			self.refresh=REFRESH.enhanced
-		elif recv_capa.announced(CID.ROUTE_REFRESH) and sent_capa.announced(CID.ROUTE_REFRESH):
-			self.refresh=REFRESH.normal
+		if recv_capa.announced(Capability.CODE.ENHANCED_ROUTE_REFRESH) and sent_capa.announced(Capability.CODE.ENHANCED_ROUTE_REFRESH):
+			self.refresh = REFRESH.ENHANCED  # pylint: disable=E1101
+		elif recv_capa.announced(Capability.CODE.ROUTE_REFRESH) and sent_capa.announced(Capability.CODE.ROUTE_REFRESH):
+			self.refresh = REFRESH.NORMAL  # pylint: disable=E1101
 
-		self.multisession = sent_capa.announced(CID.MULTISESSION_BGP) and recv_capa.announced(CID.MULTISESSION_BGP)
+		self.multisession  = sent_capa.announced(Capability.CODE.MULTISESSION) and recv_capa.announced(Capability.CODE.MULTISESSION)
+		self.multisession |= sent_capa.announced(Capability.CODE.MULTISESSION_CISCO) and recv_capa.announced(Capability.CODE.MULTISESSION_CISCO)
 
 		if self.multisession:
-			sent_ms_capa = set(sent_capa[CID.MULTISESSION_BGP])
-			recv_ms_capa = set(recv_capa[CID.MULTISESSION_BGP])
+			sent_ms_capa = set(sent_capa[Capability.CODE.MULTISESSION])
+			recv_ms_capa = set(recv_capa[Capability.CODE.MULTISESSION])
 
 			if sent_ms_capa == set([]):
-				sent_ms_capa = set([CID.MULTIPROTOCOL_EXTENSIONS])
+				sent_ms_capa = set([Capability.CODE.MULTIPROTOCOL])
 			if recv_ms_capa == set([]):
-				recv_ms_capa = set([CID.MULTIPROTOCOL_EXTENSIONS])
+				recv_ms_capa = set([Capability.CODE.MULTIPROTOCOL])
 
 			if sent_ms_capa != recv_ms_capa:
 				self.multisession = (2,8,'multisession, our peer did not reply with the same sessionid')
@@ -88,34 +94,34 @@ class Negotiated (object):
 
 			for capa in sent_ms_capa:
 				# no need to check that the capability exists, we generated it
-				# checked it is what we sent and only send MULTIPROTOCOL_EXTENSIONS
+				# checked it is what we sent and only send MULTIPROTOCOL
 				if sent_capa[capa] != recv_capa[capa]:
 					self.multisession = (2,8,'when checking session id, capability %s did not match' % str(capa))
 					break
 
-		elif sent_capa.announced(CID.MULTISESSION_BGP):
+		elif sent_capa.announced(Capability.CODE.MULTISESSION):
 			self.multisession = (2,9,'multisession is mandatory with this peer')
 
 		# XXX: Does not work as the capa is not yet defined
-		#if received_open.capabilities.announced(CID.EXTENDED_MESSAGE) \
-		#and sent_open.capabilities.announced(CID.EXTENDED_MESSAGE):
-		#	if self.peer.bgp.received_open_size:
-		#		self.received_open_size = self.peer.bgp.received_open_size - 19
+		# if received_open.capabilities.announced(Capability.CODE.EXTENDED_MESSAGE) \
+		# and sent_open.capabilities.announced(Capability.CODE.EXTENDED_MESSAGE):
+		# 	if self.peer.bgp.received_open_size:
+		# 		self.received_open_size = self.peer.bgp.received_open_size - 19
 
-	def validate (self,neighbor):
+	def validate (self, neighbor):
 		if not self.asn4:
 			if neighbor.local_as.asn4():
 				return (2,0,'peer does not speak ASN4, we are stuck')
 			else:
 				# we will use RFC 4893 to convey new ASN to the peer
-				self.asn4
+				# XXX: FIXME
+				pass
 
 		if self.peer_as != neighbor.peer_as:
 			return (2,2,'ASN in OPEN (%d) did not match ASN expected (%d)' % (self.received_open.asn,neighbor.peer_as))
 
 		# RFC 6286 : http://tools.ietf.org/html/rfc6286
-		#if message.router_id == RouterID('0.0.0.0'):
-		#	message.router_id = RouterID(ip)
+		# XXX: FIXME: check that router id is not self
 		if self.received_open.router_id == RouterID('0.0.0.0'):
 			return (2,3,'0.0.0.0 is an invalid router_id')
 
@@ -136,6 +142,7 @@ class Negotiated (object):
 
 # =================================================================== RequirePath
 
+
 class RequirePath (object):
 	REFUSE = 0
 	ACCEPT = 1
@@ -145,14 +152,14 @@ class RequirePath (object):
 		self._send = {}
 		self._receive = {}
 
-	def setup (self,received_open,sent_open):
+	def setup (self, received_open, sent_open):
 		# A Dict always returning False
 		class FalseDict (dict):
-			def __getitem__(self,key):
+			def __getitem__ (self, key):
 				return False
 
-		receive = received_open.capabilities.get(CID.ADD_PATH,FalseDict())
-		send = sent_open.capabilities.get(CID.ADD_PATH,FalseDict())
+		receive = received_open.capabilities.get(Capability.CODE.ADD_PATH,FalseDict())
+		send = sent_open.capabilities.get(Capability.CODE.ADD_PATH,FalseDict())
 
 		# python 2.4 compatibility mean no simple union but using sets.Set
 		union = []
@@ -163,8 +170,8 @@ class RequirePath (object):
 			self._send[k] = bool(receive.get(k,self.REFUSE) & self.ANNOUNCE and send.get(k,self.REFUSE) & self.ACCEPT)
 			self._receive[k] = bool(receive.get(k,self.REFUSE) & self.ACCEPT and send.get(k,self.REFUSE) & self.ANNOUNCE)
 
-	def send (self,afi,safi):
+	def send (self, afi, safi):
 		return self._send.get((afi,safi),False)
 
-	def receive (self,afi,safi):
+	def receive (self, afi, safi):
 		return self._receive.get((afi,safi),False)
