@@ -3,15 +3,20 @@
 address.py
 
 Created by Thomas Mangin on 2012-07-16.
-Copyright (c) 2009-2013 Exa Networks. All rights reserved.
+Copyright (c) 2009-2015 Exa Networks. All rights reserved.
 """
 
-from exabgp.protocol.family import AFI,SAFI
+from exabgp.protocol.family import AFI
+from exabgp.protocol.family import SAFI
 
-## =================================================================== Address
+
+# ====================================================================== Address
+#
 
 class Address (object):
-	def __init__ (self,afi,safi):
+	__slots__ = ['afi','safi']
+
+	def __init__ (self, afi, safi):
 		self.afi = AFI(afi)
 		self.safi = SAFI(safi)
 
