@@ -1,11 +1,18 @@
 from .connection import Connection
-from .tcp import create,bind,connect,MD5,nagle,TTL,async,ready
+from .tcp import create,bind
+from .tcp import connect
+from .tcp import MD5
+from .tcp import nagle
+from .tcp import TTL
+from .tcp import async
+from .tcp import ready
 from .error import NetworkError
 
+
 class Outgoing (Connection):
 	direction = 'outgoing'
 
-	def __init__ (self,afi,peer,local,port=179,md5='',ttl=None):
+	def __init__ (self, afi, peer, local, port=179,md5='',ttl=None):
 		Connection.__init__(self,afi,peer,local)
 
 		self.logger.wire("Attempting connection to %s" % self.peer)
@@ -18,14 +25,15 @@ class Outgoing (Connection):
 
 		try:
 			self.io = create(afi)
-			MD5(self.io,peer,port,afi,md5)
+			MD5(self.io,peer,port,md5)
 			bind(self.io,local,afi)
 			async(self.io,peer)
 			connect(self.io,peer,port,afi,md5)
 			self.init = True
-		except NetworkError:
+		except NetworkError,exc:
 			self.init = False
 			self.close()
+			self.logger.wire("Connection failed, %s" % str(exc))
 
 	def establish (self):
 		if not self.init:
