@@ -3,7 +3,7 @@
 usage.py
 
 Created by Thomas Mangin on 2009-09-06.
-Copyright (c) 2009-2013 Exa Networks. All rights reserved.
+Copyright (c) 2009-2015 Exa Networks. All rights reserved.
 """
 
 import sys
@@ -16,6 +16,7 @@ else:
 	# other OS (AFAIK) return a number of pages
 	divisor = 1024.0*1024.0/resource.getpagesize()
 
+
 def usage (label='usage'):
-	usage=resource.getrusage(resource.RUSAGE_SELF)
-	return '%s: usertime=%s systime=%s mem=%s mb' % (label,usage.ru_utime,usage.ru_stime,(usage.ru_maxrss/divisor))
+	rusage = resource.getrusage(resource.RUSAGE_SELF)
+	return '%s: usertime=%s systime=%s mem=%s mb' % (label,rusage.ru_utime,rusage.ru_stime,(rusage.ru_maxrss/divisor))
